@@ -170,7 +170,7 @@ def _unlisted_devices(pci_addrs):
 def _is_dpdk_dev(dev):
     return (dev.get('class') == 'network' and 'handle' in dev and
             'logicalname' not in dev and
-            dev['configuration']['driver'] in DPDK_DRIVERS and
+            dev['configuration'].get('driver') in DPDK_DRIVERS and
             'Virtual Function' not in dev.get('product', ''))
 
 
