@@ -18,6 +18,7 @@
 # Refer to the README and COPYING files for full details of the license
 #
 
+import io
 import json
 import os
 import pprint
@@ -185,6 +186,7 @@ class TestSupportsOption(TestCaseBase):
 
         with MonkeyPatchScope([(commands, 'execCmd', fake_cmd)]):
             self.assertTrue(qemuimg._supports_option('create', 'u'))
+            self.assertTrue(qemuimg.supports_unsafe_create())
             self.assertTrue(qemuimg._supports_option('info', 'U'))
             self.assertFalse(qemuimg._supports_option('map', 'U'))
 
@@ -201,6 +203,7 @@ class TestSupportsOption(TestCaseBase):
 
         with MonkeyPatchScope([(commands, 'execCmd', fake_cmd)]):
             self.assertFalse(qemuimg._supports_option('create', 'u'))
+            self.assertFalse(qemuimg.supports_unsafe_create())
             self.assertFalse(qemuimg._supports_option('info', 'U'))
 
 
@@ -278,6 +281,15 @@ class CreateTests(TestCaseBase):
             with self.assertRaises(exception.InvalidConfiguration):
                 qemuimg.create('image', format='qcow2')
 
+    @MonkeyPatch(qemuimg, 'config', CONFIG)
+    def test_unsafe_create_volume(self):
+        with namedTemporaryDir() as tmpdir:
+            path = os.path.join(tmpdir, 'test.qcow2')
+            # Using unsafe=True to verify that it is possible to create an
+            # image based on a non-existing backing file, like an inactive LV.
+            qemuimg.create(path, size=1048576, format=qemuimg.FORMAT.QCOW2,
+                           backing='no-such-file', unsafe=True)
+
 
 class ConvertTests(TestCaseBase):
 
@@ -364,6 +376,63 @@ class ConvertTests(TestCaseBase):
                             dstQcow2Compat='1.11')
 
 
+@expandPermutations
+class TestConvertPreallocation(TestCaseBase):
+
+    @permutations([
+        # preallocation, virtual_size, actual_size
+        (None, 10 * 1024**2, 0),
+        (qemuimg.PREALLOCATION.OFF, 10 * 1024**2, 0),
+        (qemuimg.PREALLOCATION.FALLOC, 10 * 1024**2, 10 * 1024**2),
+        (qemuimg.PREALLOCATION.FULL, 10 * 1024**2, 10 * 1024**2),
+    ])
+    def test_raw_to_raw(self, preallocation, virtual_size, actual_size):
+        with namedTemporaryDir() as tmpdir:
+            src = os.path.join(tmpdir, 'src')
+            dst = os.path.join(tmpdir, 'dst')
+
+            with io.open(src, "wb") as f:
+                f.truncate(virtual_size)
+
+            op = qemuimg.convert(src, dst, srcFormat="raw", dstFormat="raw",
+                                 preallocation=preallocation)
+            op.run()
+
+            stat = os.stat(dst)
+            self.assertEqual(stat.st_size, virtual_size)
+            self.assertEqual(stat.st_blocks * 512, actual_size)
+
+    @permutations([
+        # preallocation, virtual_size, actual_size
+        (None, 10 * 1024**2, 0),
+        (qemuimg.PREALLOCATION.OFF, 10 * 1024**2, 0),
+        (qemuimg.PREALLOCATION.FALLOC, 10 * 1024**2, 10 * 1024**2),
+        (qemuimg.PREALLOCATION.FULL, 10 * 1024**2, 10 * 1024**2),
+        (qemuimg.PREALLOCATION.FULL, 10 * 1024**2, 10 * 1024**2),
+    ])
+    def test_qcow2_to_raw(self, preallocation, virtual_size, actual_size):
+        with namedTemporaryDir() as tmpdir:
+            src = os.path.join(tmpdir, 'src')
+            dst = os.path.join(tmpdir, 'dst')
+
+            op = qemuimg.create(src, size=virtual_size, format="qcow2")
+            op.run()
+
+            op = qemuimg.convert(src, dst, srcFormat="qcow2", dstFormat="raw",
+                                 preallocation=preallocation)
+            op.run()
+
+            stat = os.stat(dst)
+            self.assertEqual(stat.st_size, virtual_size)
+            self.assertEqual(stat.st_blocks * 512, actual_size)
+
+    def test_raw_invalid_preallocation(self):
+        with self.assertRaises(ValueError):
+            qemuimg.convert(
+                'src', 'dst', dstFormat="raw",
+                preallocation=qemuimg.PREALLOCATION.METADATA)
+
+
 class CheckTests(TestCaseBase):
 
     @MonkeyPatch(qemuimg, 'config', CONFIG)
