@@ -792,9 +792,20 @@ _STORAGE_TEST_DATA = [
                 startupPolicy="optional" />
             <target bus="ide" dev="hdd" />
             <readonly />
+            <driver error_policy="report" io="threads"
+                name="qemu" type="raw" />
         </disk>'''.format(guid='8a1dc504-9d00-48f3-abdc-c70404e6f7e2',
                           hashsum='4137dc5fb55e021fbfd2653621d9d194'),
      {}],
+    # cdrom from Engine 4.2.0, using error_policy="report"
+    [u'''<disk type="file" device="cdrom" snapshot="no">
+            <address bus="1" controller="0" unit="0" type="drive" target="0"/>
+            <source file="" startupPolicy="optional"/>
+            <target dev="hdc" bus="ide"/>
+            <readonly/>
+            <driver name="qemu" type="raw" io="threads" error_policy="report"/>
+         </disk>''',
+     {}],
     [u'''<disk device="disk" snapshot="no" type="block">
             <source dev="/path/to/volume"/>
             <target bus="virtio" dev="vda"/>
@@ -1320,6 +1331,42 @@ class DeviceXMLRoundTripTests(XMLTestCase):
         )
         self._check_device_xml(dev, expected_xml)
 
+    def test_cdrom_from_xml_without_driver_element(self):
+        # test that we add the 'driver' element with the
+        # defaults in in the XML-based initialization flow
+
+        # this is the common XML template.
+        cdrom_xml = u'''
+            <disk type="file" device="cdrom" snapshot="no">
+                <address bus="1" controller="0" unit="0"
+                         type="drive" target="0"/>
+                <source file="" startupPolicy="optional"/>
+                <target dev="hdc" bus="ide"/>
+                <readonly/>
+                {driver_xml}
+            </disk>'''
+        # simulate we receive a XML snippet without the driver
+        # element. This is unlikely with Engine >= 4.2, but still
+        # supported.
+        source_xml = cdrom_xml.format(driver_xml='')
+        # The output XML must include a "driver" element, built
+        # using the defaults. Everything else should be the same
+        # (see below for more details).
+        expected_xml = cdrom_xml.format(
+            driver_xml=u'''<driver name="qemu" type="raw" io="threads"
+            error_policy="stop"/>''')
+
+        dev = vmdevices.storage.Drive(
+            self.log, **vmdevices.storagexml.parse(
+                vmxml.parse_xml(source_xml),
+                {}
+            )
+        )
+        # everything which is not related to the driver element should be
+        # derived from the source XML, thus the source and the expected
+        # XML snippets should be equal - bar the driver element.
+        self._check_device_xml(dev, expected_xml)
+
     def _check_roundtrip(self, klass, dev_xml, meta=None, expected_xml=None):
         dev = klass.from_xml_tree(
             self.log,
@@ -1365,6 +1412,7 @@ _DRIVE_PAYLOAD_XML = u"""<domain type='kvm' id='2'>
       <source startupPolicy='optional'/>
       <target dev='hdd' bus='ide'/>
       <readonly/>
+      <driver error_policy="report" io="threads" name="qemu" type="raw" />
     </disk>
   </devices>
 </domain>"""
@@ -1459,6 +1507,7 @@ _DOMAIN_MD_MATCH_XML = u"""<domain type='kvm' id='2'>
       <backingStore/>
       <target dev='hdc' bus='ide'/>
       <readonly/>
+      <driver error_policy="report" io="threads" name="qemu" type="raw" />
     </disk>
     <controller type='virtio-serial' index='0' ports='16'>
       <alias name='virtio-serial0'/>
